﻿function Get-BITSStatus
{
    [CmdletBinding(SupportsShouldProcess=$true, 
                  PositionalBinding=$false,
                  ConfirmImpact='Medium')]
    [Alias()]
    [OutputType([PSOBJECT])]

    param (
        [Parameter(Mandatory=$False, ParameterSetName='ELHC')]
        [ValidateNotNullOrEmpty()]
        [PSObject]$ELHCConfig = $false
    )

    $Srv = Get-Service | ?{$_.DisplayName -match 'Background Intelligent Transfer Service'}
    
    $Installed = $false
    $Status = "N/A"
    $Jobs = "N/A"
    
    if ($Srv -ne $null) {
        $Installed = $true
        $Status = $Srv.Status.ToString()
        try {
            $Jobs = (Get-BitsTransfer -AllUsers).Count
            $WGVJobs = (Get-BitsTransfer -AllUsers | ?{$_.displayname -match 'wgv'}).count
            $ErroredWGVJobs = (Get-BitsTransfer -AllUsers | ?{$_.displayname -match 'wgv'} | ?{$_.JobState -match 'Error'}).count
        }
        catch {
            Write-Warning "Couldn't get BITS jobs.  Make sure to run Powershell as admin."
        }
    }

    $AlertErrorJobs = [int]$ELHCConfig.root.components.standalone.component.bitsstatus.alerts.allowedErrorJobs


    $AlertBool = $false
    if ($ErroredWGVJobs -gt $AlertErrorJobs -or !$Installed -or $Status -ne 'Running') {
        $AlertBool = $true
    }
    

    $Results = @{
        'LogType' = 'BITSStatus'
        'BITS_Installed' = $Installed
        'BITS_Status' = $Status
        'BITS_TotalJobs' = $Jobs
        'BITS_WGVJobs' = $WGVJobs
        'BITS_ErrorWGVJobs' = $ErroredWGVJobs
        'AlertErrorJobs' = $AlertErrorJobs
        'AlertBool' = $AlertBool

    }

    return $Results
}
