﻿<#
    .Synopsis
    Short description
    .DESCRIPTION
    Long description
    .EXAMPLE
    Example of how to use this cmdlet
    .EXAMPLE
    Another example of how to use this cmdlet
    .INPUTS
    Inputs to this cmdlet (if any)
    .OUTPUTS
    Output from this cmdlet (if any)
    .NOTES
    General notes
    .COMPONENT
    The component this cmdlet belongs to
    .ROLE
    The role this cmdlet belongs to
    .FUNCTIONALITY
    The functionality that best describes this cmdlet
#>
function Get-EventStatus
{
    [CmdletBinding(SupportsShouldProcess=$true, 
                  PositionalBinding=$false,
                  ConfirmImpact='Medium')]
    [Alias()]
    [OutputType([PSOBJECT])]
    
    param (
        [Parameter(Mandatory=$True, ParameterSetName='ELHC')]
        [ValidateNotNullOrEmpty()]
        [PSObject]$ELHCConfig = $false,

        [Parameter(Mandatory=$False, ParameterSetName='External')]
        [ValidateNotNullOrEmpty()]
        [string]$ConnectionString = "data source=(local);initial catalog=WGEvidenceLibrary;integrated security=true;connection lifetime=30;"
    )

    if($ELHCConfig) {
        $ConnectionString = $ELHCConfig.root.ConnectionString
    }

    $Query ="SELECT COUNT(*) as Number,
	                CASE WHEN EventStatus = '0' THEN 'NotSet'
		                 WHEN EventStatus = '1' THEN 'Importing'
		                 WHEN EventStatus = '2' THEN 'Online'
		                 WHEN EventStatus = '3' THEN 'Partial'
		                 WHEN EventStatus = '4' THEN 'ArchivePending'
		                 WHEN EventStatus = '5' THEN 'Archived'
		                 WHEN EventStatus = '6' THEN 'RestorePending'
		                 WHEN EventStatus = '7' THEN 'Restored'
		                 WHEN EventStatus = '8' THEN 'PurgePending'
		                 WHEN EventStatus = '9' THEN 'Purged'
		                 WHEN EventStatus = '10' THEN 'ImportIdle'
		                 WHEN EventStatus = '32767' THEN 'Faulted'
	                ELSE 'Unknown' END AS EventStatus 
                FROM dbo.RecordingEvent
                where SubstationID = '$($ELHCConfig.root.substationID)'
                GROUP BY EventStatus"

    $EventCats = Get-QueryResult -query $Query -connectionString $ConnectionString

    $Return = @{
        'LogType' = 'EventStatus'
    }

    foreach ($line in $EventCats) {
        $Return.Add($line.EventStatus, $line.Number)
    }

    return $Return
}