﻿function Get-IISStatus
{
    [CmdletBinding(SupportsShouldProcess=$true, 
                  PositionalBinding=$false,
                  ConfirmImpact='Medium')]
    [Alias()]
    [OutputType([PSOBJECT])]

    param (
        [Parameter(Mandatory=$False, ParameterSetName='ELHC')]
        [ValidateNotNullOrEmpty()]
        [PSObject]$ELHCConfig = $false
    )

    $Srv = Get-Service "*W3SVC*"
    
    $Installed = $false
    $Status = "N/A"
    
    if ($Srv -ne $null) {
        $Installed = $true
        $Status = $Srv.Status.ToString()
    }

    $AlertBool = $false
    if ($Installed -ne $true -or $Status -ne 'Running') {
        $AlertBool = $true
    }


    $Results = @{
        'LogType' = 'IISStatus'
        'IIS_Installed' = $Installed
        'IIS_Status' = $Status
        'AlertBool' = $AlertBool
    }

    return $Results
}

Export-ModuleMember -Cmdlet Get-IISStatus