﻿function Get-JobQueueInfo
{
    [CmdletBinding(SupportsShouldProcess=$true, 
                  PositionalBinding=$false,
                  ConfirmImpact='Medium')]
    [Alias()]
    [OutputType([PSOBJECT])]

    param (
        [Parameter(Mandatory=$True, ParameterSetName='ELHC')]
        [ValidateNotNullOrEmpty()]
        [PSObject]$ELHCConfig = $false,

        [Parameter(Mandatory=$False, ParameterSetName='External')]
        [ValidateNotNullOrEmpty()]
        [string]$ConnectionString = "data source=(local);initial catalog=WGEvidenceLibrary;integrated security=true;connection lifetime=30;"
    )

    if($ELHCConfig) {
        $ConnectionString = $ELHCConfig.root.ConnectionString
    }

    $ConcatQuery = (
        "select COUNT(*) as Pending
        from JobQueue.ConcatEventQueue
        where SubstationID = '$($ELHCConfig.root.substationID)'"
    )

    $ConcatCount = (Get-QueryResult -query $ConcatQuery -connectionString $ConnectionString).Pending

    $TranscodeQuery = (
        "select COUNT(*) as Pending
        from JobQueue.TranscodeQueue
        WHERE SubstationID = '$($ELHCConfig.root.substationID)'"
    )

    $TranscodeCount = (Get-QueryResult -query $TranscodeQuery -connectionString $ConnectionString).Pending
    
    $AlertBool = $false
    $AlertConcatJobs = [int]$ELHCConfig.root.components.standalone.component.jobqueue.alerts.allowedconcats
    $AlertTranscodeJobs = [int]$ELHCConfig.root.components.standalone.component.jobqueue.alerts.allowedtrans
    if ($ConcatCount -gt $AlertConcatJobs) {
        $AlertBool = $true
    }
    
    if ($TranscodeCount -gt $AlertTranscodeJobs) {
        $AlertBool = $true
    }

    $Results = @{
        'LogType' = "JobQueueInfo"
        'ConcatsPending' = $ConcatCount
        'TranscodesPending' = $TranscodeCount
        'AlertConcatJobs' = $AlertConcatJobs
        'AlertTranscodeJobs' = $AlertTranscodeJobs
        'AlertBool' = $AlertBool
    }

    return $Results
}