﻿<#
    .Synopsis
    Short description
    .DESCRIPTION
    Long description
    .EXAMPLE
    Example of how to use this cmdlet
    .EXAMPLE
    Another example of how to use this cmdlet
    .INPUTS
    Inputs to this cmdlet (if any)
    .OUTPUTS
    Output from this cmdlet (if any)
    .NOTES
    General notes
    .COMPONENT
    The component this cmdlet belongs to
    .ROLE
    The role this cmdlet belongs to
    .FUNCTIONALITY
    The functionality that best describes this cmdlet
#>
function Get-StorageInfo
{
    [CmdletBinding(SupportsShouldProcess=$true, 
                  PositionalBinding=$false,
                  ConfirmImpact='Medium')]
    [Alias()]
    [OutputType([PSOBJECT])]

    param (
        [Parameter(Mandatory=$True, ParameterSetName='ELHC')]
        [ValidateNotNullOrEmpty()]
        [PSOBJECT]$ELHCConfig = $false,

        [Parameter(Mandatory=$True, ParameterSetName='ELHC')]
        [ValidateNotNullOrEmpty()]
        [psobject]$AvduRow = $false,

        [Parameter(Mandatory=$True, ParameterSetName='External')]
        [ValidateNotNullOrEmpty()]
        [string]$ShareName
    )
    
    if ($ELHCConfig -and $AvduRow) {
        $ShareName = $AvduRow.Path.Split("\")[[int](($AvduRow.Path.Split("\").Length)-1)]
    }

    function Get-ShareSizes {
        param ( 
        [Parameter(Mandatory=$false)]
        [string]$name
        )
        $GBConversion = [math]::Pow(1024,3)
        $Shares = Get-WMIObject Win32_Share | where {$_.Name -eq $name}
        $Volumes = Get-WMIObject Win32_Volume
        Foreach ($Share in $Shares) { 
            If ($Share.Type -eq 0) { 
                $Result = "" | Select Server, Share, Path, Used, Free, Total, Percent
                $Result.Server=$Share.__SERVER
                $Result.Share=$Share.Name
                $Result.Path=$Share.Path
                $ShareVolume="" | Select Name 
                Foreach ($Volume in $Volumes) { 
                    If ( ($Result.Path.Length -ge $Volume.Name.Length) -and ($Volume.Name.Length -gt $ShareVolume.Name.Length) ) { 
                        If ($Result.Path.Substring(0,$Volume.Name.Length) -eq $Volume.Name) {
                            $ShareVolume = $Volume 
                        } 
                    } 
                }
                #$Result.Volume=$ShareVolume.Name; 
                $Result.Total=[math]::Round($ShareVolume.Capacity / $GBConversion, 2)
                $Result.Free=[math]::Round($ShareVolume.FreeSpace / $GBConversion, 2)
                $Result.Used=[math]::Round(($ShareVolume.Capacity - $ShareVolume.FreeSpace) / $GBConversion, 2)
                $Percent = [math]::Round($(($Result.Used / $Result.Total)*100),1)
                $Result.Percent=$Percent
                return $Result
            } 
        }
    }

    $DiskInfo = Get-ShareSizes -name $ShareName

    $AllowedUsage = [int]$ELHCConfig.root.components.avdurow.component.storageinfo.alerts.allowedusage
    $AlertBool = $false
    if ($DiskInfo.Percent -gt $AllowedUsage) {
        $AlertBool = $true
    }

    $Return = @{
        'LogType' = 'StorageInfo'
        'StoragePC' = $DiskInfo.Server
        'StoragePathLocal' = $DiskInfo.Path
        'StorageDiskSize(GB)' = $DiskInfo.Total
        'StorageDiskFree(GB)' = $DiskInfo.Free
        'StorageDiskUsed(GB)' = $DiskInfo.Used
        'StorageDiskUsage(%)' = $DiskInfo.Percent
        'ShareName' = $ShareName
        'AlertAllowedUsage' = $AllowedUsage
        'AlertBool' = $AlertBool
    }
    
    return $Return
    
}