﻿<#
    .Synopsis
    Short description
    .DESCRIPTION
    Long description
    .EXAMPLE
    Example of how to use this cmdlet
    .EXAMPLE
    Another example of how to use this cmdlet
    .INPUTS
    Inputs to this cmdlet (if any)
    .OUTPUTS
    Output from this cmdlet (if any)
    .NOTES
    General notes
    .COMPONENT
    The component this cmdlet belongs to
    .ROLE
    The role this cmdlet belongs to
    .FUNCTIONALITY
    The functionality that best describes this cmdlet
#>
function Test-ACLPermissions
{
    [CmdletBinding(SupportsShouldProcess=$true, 
                  PositionalBinding=$false,
                  ConfirmImpact='Medium')]
    [Alias()]
    [OutputType([PSOBJECT])]
    param (
        [Parameter(Mandatory=$True, ParameterSetName='ELHC')]
        [ValidateNotNullOrEmpty()]
        [PSOBJECT]$ELHCConfig = $false,

        [Parameter(Mandatory=$True, ParameterSetName='ELHC')]
        [ValidateNotNullOrEmpty()]
        [psobject]$AvduRow = $false,

        [Parameter(Mandatory=$False, ParameterSetName='External')]
        #[ValidateScript({$_.Gettype() -match 'Array'})]
        [System.Array]$Users = @('WGV.NET', 'EVERYONE', 'SYSTEM', 'NETWORK SERVICE', 'LOCAL SERVICE'),

        [Parameter(Mandatory=$True, ParameterSetName='External', position=0)]
        [ValidateNotNullOrEmpty()]
        [string]$Path
    )
    
    if ($ELHCConfig -and $AvduRow) {
        $Path = $AvduRow.Path
        $Users = $ELHCConfig.root.components.avdurow.component.ACLPermissions.ACLUsers.value
    }

    $Failure = @{
            'Path' = $Path
            'LogType' = 'ACLPermissions'
            'AlertBool' = $false
            'ShareStatus' = 'Inaccessible'
    }
    
    try {
        if (Test-Path $Path) {
            $ACLShareAccess = (Get-Acl -Path $Path).Access
        }
        else {
            return $Failure
        }
    }
    catch {
        return $Failure
    }

    function ACLCheckUser {
        param (
            [Parameter(Mandatory=$True, Position=0)]
            [string]$User,

            [Parameter(Mandatory=$True, Position=1)]
            [System.Collections.ReadOnlyCollectionBase]$ACLInput
        )
        
        $ACLUserAccess = $ACLInput | Where-Object {$_.IdentityReference -like "*$User*"}
        if ($ACLUserAccess -ne $null) {
            if ($ACLUserAccess.FileSystemRights -match 'FullControl') {
                return 'Correct'
            }
            return 'Incorrect'
        }
        return 'N/A'
    }
    
    $AlertUsers = $ELHCConfig.root.components.avdurow.component.aclpermissions.alerts.value
    $Return = @{}

    ForEach ($User in $Users) {
        $UserPermissions = ACLCheckUser -User $User -ACLInput $ACLShareAccess
        #Write-Output $User
        $Return.Add("$($User.Replace(' ',''))_Perms", $UserPermissions)
    }
    $Return += @{
        'Path' = $Path
        'LogType' = 'ACLPermissions'
        'ShareStatus' = 'Accessible'
        'SVCACCT_Perms' = ACLCheckUser $env:USERNAME -ACLInput $ACLShareAccess
    }

    $AlertBool = $false
    if ($ELHCConfig) {
        foreach ($User in $AlertUsers) {
            $User = $User.Replace(' ','')
            if ($Return."$($User)_Perms" -ne 'Correct') {
                $AlertBool = $true
            }
        }
        $Return += @{'AlertBool' = $false}
    }
    
    return $Return

}
