﻿<#
    .Synopsis
    Short description
    .DESCRIPTION
    Long description
    .EXAMPLE
    Example of how to use this cmdlet
    .EXAMPLE
    Another example of how to use this cmdlet
    .INPUTS
    Inputs to this cmdlet (if any)
    .OUTPUTS
    Output from this cmdlet (if any)
    .NOTES
    General notes
    .COMPONENT
    The component this cmdlet belongs to
    .ROLE
    The role this cmdlet belongs to
    .FUNCTIONALITY
    The functionality that best describes this cmdlet
#>

#fix 


function Test-SharePermissions
{
    [CmdletBinding(SupportsShouldProcess=$true, 
                  PositionalBinding=$false,
                  ConfirmImpact='Medium')]
    [Alias()]
    [OutputType([PSOBJECT])]
    Param (
        [Parameter(Mandatory=$True, ParameterSetName='ELHC')]
        [ValidateNotNullOrEmpty()]
        [PSOBJECT]$ELHCConfig = $false,

        [Parameter(Mandatory=$True, ParameterSetName='ELHC')]
        [ValidateNotNullOrEmpty()]
        [psobject]$AvduRow = $false,

        [Parameter(Mandatory=$True, ParameterSetName='External', position=0)]
        [ValidateNotNullOrEmpty()]
        [string]$ShareName,

        [Parameter(Mandatory=$False, ParameterSetName='External')]
        [ValidateScript({ $_.GetType().Name -match 'String'})]
        [string]$SMBUsers = 'Everyone',

        [Parameter(Mandatory=$False, ParameterSetName='External')]
        [ValidateScript({ $_.GetType().Name -match 'String'})]
        [string]$PCName = $env:COMPUTERNAME
    )

    if ($AvduRow -and $ELHCConfig) {
        [system.array]$SMBUsers = $ELHCConfig.root.components.avdurow.component.SharePermissions.SMBUsers.value; $SMBUsers += @($env:USERNAME)
        $SMBUsersAlert = $ELHCConfig.root.components.avdurow.component.SharePermissions.alerts.value
        $ShareName = $AvduRow.Path.Split("\")[($AvduRow.Path.Split("\").Length - 1)]
        $PCName = $AvduRow.Path.Split("\")[2]
        $AlertBool = $false

    }

    #initialize results hashtable
    $Results = @{
        'LogType' = 'SharePermissions'
        'PCName' = $PCName
        'AlertBool' = $false
        'ShareName' = $ShareName
        'SMBUsers' = $SMBUsers
    }

    #if our SMB share is remote, not much to do.  Log and exit.
    if ($PCName -notmatch $env:COMPUTERNAME) {
        $Results += @{
            'ShareLocation' = 'Remote'
        }
        return $Results
    }
    
    #make sure we can access our share
    if (Test-Path "\\$env:COMPUTERNAME\$ShareName") {
       $ACL = Get-SmbShareAccess -Name $ShareName 
    }
    else {
        $Results += @{'ShareStatus' = 'Inaccessible'}
        return $Results
    }
    
    #Log our permissions for each user specified in config/args
    foreach ($SMBUser in $SMBUsers) {
        $UserPerms = ($ACL | Where-Object {$_.AccountName -match $SMBUser}).AccessRight
        if ($UserPerms -eq $null) {
            $UserPerms = 'N/A'
        }

        if ($SMBUser -eq $env:USERNAME) {
            $Results += @{'SVCACCT' = $UserPerms}
        }
        else {
            $Results += @{$SMBUser = $UserPerms}
        }
    }


    #check permissions against the alert perms in config
    if ($ELHCConfig -and $AvduRow) {
        foreach ($SMBAlert in $SMBUsersAlert) {
            if ($Results.$SMBAlert -ne 'Full') {
                $AlertBool = $true
            }
        }
        $Results += @{'AlertBool' = $AlertBool}
    }

    $Results += @{'ShareStatus' = 'Accessible'}
    $Results
   
}
