﻿<#
    .Synopsis
    Short description
    .DESCRIPTION
    Long description
    .EXAMPLE
    Example of how to use this cmdlet
    .EXAMPLE
    Another example of how to use this cmdlet
    .INPUTS
    Inputs to this cmdlet (if any)
    .OUTPUTS
    Output from this cmdlet (if any)
    .NOTES
    General notes
    .COMPONENT
    The component this cmdlet belongs to
    .ROLE
    The role this cmdlet belongs to
    .FUNCTIONALITY
    The functionality that best describes this cmdlet
#>

#fix 


function Test-SharePermissions
{
    [CmdletBinding(SupportsShouldProcess=$true, 
                  PositionalBinding=$false,
                  ConfirmImpact='Medium')]
    [Alias()]
    [OutputType([PSOBJECT])]
    Param (
        [Parameter(Mandatory=$True, ParameterSetName='ELHC')]
        [ValidateNotNullOrEmpty()]
        [PSOBJECT]$ELHCConfig = $false,

        [Parameter(Mandatory=$True, ParameterSetName='ELHC')]
        [ValidateNotNullOrEmpty()]
        [psobject]$AvduRow = $false,

        [Parameter(Mandatory=$True, ParameterSetName='External', position=0)]
        [ValidateNotNullOrEmpty()]
        [string]$ShareName,

        [Parameter(Mandatory=$False, ParameterSetName='External')]
        [ValidateScript({ $_.GetType().Name -match 'String'})]
        [string]$Group = 'Everyone',
        
        [Parameter (Mandatory=$False, ParameterSetName='External')]
        #[ValidateScript({ $_.GetType().Name -match 'Int32'})]
        [int]$AccessMask = '2032127',

        [Parameter(Mandatory=$False, ParameterSetName='External')]
        [ValidateScript({ $_.GetType().Name -match 'String'})]
        [string]$PCName = $env:COMPUTERNAME
    )

    if ($AvduRow -and $ELHCConfig) {
        $Group = $ELHCConfig.root.components.avdurow.component.SharePermissionsLegacy.SMBGroup
        $ShareName = $AvduRow.Path.Split("\")[($AvduRow.Path.Split("\").Length - 1)]
        $AccessMask = $ELHCConfig.root.components.avdurow.component.SharePermissionsLegacy.SMBMask
        $PCName = $AvduRow.Path.Split("\")[2]
        
        if ($PCName -notmatch $env:COMPUTERNAME) {
            return @{
            'LogType' = 'SharePermissionsLegacy'
            'PCName' = $PCName
            'PermissionGroup' = $Group
            'AccessMask' = 'N/A'
            'ContainsGroup' = 'N/A'
            'GroupMask' = 'N/A'
            'AlertBool' = $GroupMaskIncorrect
            'ShareLocation' = 'Remote'
            }
        }
    }
    

    
    $LSSS = Get-WmiObject -Class win32_logicalsharesecuritysetting -ComputerName $PCName
    $ContainsGroup = $False
    $GroupMask = 'N/A'
    $GroupMaskIncorrect = $True  
        
        
    $ShareLSSS = $LSSS | Where-Object -FilterScript {$_.Name -eq $ShareName}
    $SecDesc = $ShareLSSS.GetSecurityDescriptor()

            
    foreach ($DACL in $SecDesc.Descriptor.DACL) {
        if ($DACL.Trustee.Name -contains $Group) {
            $ContainsGroup = $True
                
            if ($DACL.AccessMask -eq $AccessMask) {
                $GroupMask = $AccessMask
                $GroupMaskIncorrect = $False
            }
                
            else {
                $GroupMask = $DACL.AccessMask
            }
        }
    }
   
    $Results = @{
        'LogType' = 'SharePermissionsLegacy'
        'PCName' = $PCName
        'PermissionGroup' = $Group
        'AccessMask' = $AccessMask
        'ContainsGroup' = $ContainsGroup
        'GroupMask' = $GroupMask
        'AlertBool' = $GroupMaskIncorrect
        'ShareLocation' = 'Local'
    }

    Return $Results
   
}
