﻿<#
.Synopsis
   Short description
.DESCRIPTION
   Long description
.EXAMPLE
   Example of how to use this cmdlet
.EXAMPLE
   Another example of how to use this cmdlet
.INPUTS
   Inputs to this cmdlet (if any)
.OUTPUTS
   Output from this cmdlet (if any)
.NOTES
   General notes
.COMPONENT
   The component this cmdlet belongs to
.ROLE
   The role this cmdlet belongs to
.FUNCTIONALITY
   The functionality that best describes this cmdlet
#>
function Test-StorageSpeed
{
    #todo add Begin, Process, End
    [CmdletBinding(SupportsShouldProcess=$true, 
                  PositionalBinding=$false,
                  ConfirmImpact='Medium')]
    [Alias()]
    [OutputType([PSOBJECT])]
        param (
        [Parameter(Mandatory=$True, ParameterSetName='ELHC')]
        [ValidateNotNullOrEmpty()]
        [PSOBJECT]$ELHCConfig = $false,

        [Parameter(Mandatory=$True, ParameterSetName='ELHC')]
        [ValidateNotNullOrEmpty()]
        [psobject]$AvduRow = $false,

        [Parameter (Mandatory=$True, ParameterSetName='External')]
        [ValidateScript({ Test-Path -Path $_ -PathType Container })]
        [string]$Destination,

        [Parameter (Mandatory=$False, ParameterSetName='External')]
        [ValidateScript({ Test-Path -Path $_ -PathType Container })]
        [string]$BasePath = $PSScriptRoot,
        
        [Parameter (Mandatory=$False, ParameterSetName='ELHC')]
        [Parameter (ParameterSetName='External')]
        [int]$BinSizeMB = 94,
        
        [Parameter (Mandatory=$False, ParameterSetName='ELHC')]
        [Parameter (ParameterSetName='External')]
        [int]$BinCount = 10
    )
    
    if ($ELHCConfig -and $AvduRow) {
        $BasePath = $PSScriptRoot
        $Destination = $AvduRow.Path
        $BinSizeMB = $ELHCConfig.root.components.avdurow.component.storagespeed.BinSize
        $BinCount = $ELHCConfig.root.components.avdurow.component.storagespeed.BinFileCount
    }

    for ($i = 0; $i -lt $BinCount; $i++) { 
        $Filename =  '{0}\{1}{2}' -f $BasePath, $i, '.bin'
        $File = [io.file]::Create($Filename)
        $File.SetLength($BinSizeMB * 1e6)
        $File.Close()
    }
    
    try {

        $TotalBinMegaBytes = $BinSizeMB * $BinCount

        #Get upload speed

        $Elapsed = (Measure-Command -Expression { robocopy $BasePath $Destination *.bin /J /MT /NP }).TotalSeconds
        $UpSpeed = [math]::Round(($TotalBinMegaBytes * 8 / $Elapsed),0)
        
        #Get download speed

        $Elapsed = (Measure-Command -Expression { robocopy $Destination $BasePath *.bin /J /MT /MOV}).TotalSeconds
        $DownSpeed = [math]::Round(($TotalBinMegaBytes * 8 / $Elapsed),0)
        
    }

    catch {
        Write-Warning "An error occurred while processing $($Destination) speedtests"
        Write-Warning "$_"
    }

    $AlertCombined = [int]$ELHCConfig.root.components.avdurow.component.storagespeed.alerts.alertcombined
    $CombinedSpeed = $UpSpeed + $DownSpeed
    $AlertBool = $false
    if ($CombinedSpeed -lt $AlertCombined) {
        $AlertBool = $true
    }

    $Results = @{
        'LogType' = 'StorageSpeed'
        'Destination' = $Destination
        'Path' = $BasePath
        'WriteMbps' = $UpSpeed
        'ReadMbps' = $DownSpeed
        'BinCount' = $BinCount
        'BinSize' = $BinSizeMB
        'CombinedSpeed' = $CombinedSpeed
        'AlertCombined' = $AlertCombined
        'AlertBool' = $AlertBool
    }  
    
    #clean up the mess
    #todo Make this more precise on what it deletes.
    Remove-Item -Path "$BasePath\*.bin*" -Force
    Remove-Item -Path "$Destination\*.bin*" -Force
    Return $Results
}
